coef.probit <- function( object, ... ) {
   result <- maxLik:::coef.maxLik( object )
   return( result )
}
